==> apache-sshd-2.13.0-src.tar.gz: apache-sshd-2.13.0/sshd-common/src/main/java/org/apache/sshd/common/util/security/bouncycastle/BouncyCastleRandomFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sshd.common.util.security.bouncycastle;

import org.apache.sshd.common.random.AbstractRandomFactory;
import org.apache.sshd.common.random.Random;
import org.apache.sshd.common.util.security.SecurityUtils;

/**
 * Named factory for the BouncyCastle <code>Random</code>
 */
public final class BouncyCastleRandomFactory extends AbstractRandomFactory {
    public static final String NAME = "bouncycastle";
    public static final BouncyCastleRandomFactory INSTANCE = new BouncyCastleRandomFactory();

    public BouncyCastleRandomFactory() {
        super(NAME);
    }

    @Override
    public boolean isSupported() {
        return SecurityUtils.isBouncyCastleRegistered();
    }

    @Override
    public Random create() {
        return new BouncyCastleRandom();
    }
}

==> apache-sshd-2.14.0-src.tar.gz: apache-sshd-2.14.0/sshd-common/src/main/java/org/apache/sshd/common/util/security/bouncycastle/BouncyCastleRandomFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sshd.common.util.security.bouncycastle;

import org.apache.sshd.common.random.AbstractRandomFactory;
import org.apache.sshd.common.random.Random;
import org.apache.sshd.common.util.security.SecurityUtils;
import org.bouncycastle.crypto.prng.RandomGenerator;

/**
 * Named factory for the BouncyCastle <code>Random</code>
 */
public final class BouncyCastleRandomFactory extends AbstractRandomFactory {
    public static final String NAME = "bouncycastle";
    public static final BouncyCastleRandomFactory INSTANCE = new BouncyCastleRandomFactory();

    public BouncyCastleRandomFactory() {
        super(NAME);
    }

    @Override
    public boolean isSupported() {
        try {
            return SecurityUtils.isBouncyCastleRegistered() && RandomGenerator.class.getName() != null;
        } catch (Throwable e) {
            return false;
        }
    }

    @Override
    public Random create() {
        return new BouncyCastleRandom();
    }
}
